@@ -10,5 +10,5 @@ class OutlinewidthValidator(_plotly_utils.basevalidators.NumberValidator):
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "colorbars"),
             min=kwargs.pop("min", 0),
-            **kwargs
+            **kwargs,
         )
