@@ -8,5 +8,5 @@ class HovertextValidator(_plotly_utils.basevalidators.StringValidator):
             parent_name=parent_name,
             array_ok=kwargs.pop("array_ok", True),
             edit_type=kwargs.pop("edit_type", "style"),
-            **kwargs
+            **kwargs,
         )
