@@ -9,7 +9,6 @@ class CategoryorderValidator(_plotly_utils.basevalidators.EnumeratedValidator):
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "plot"),
-            role=kwargs.pop("role", "info"),
             values=kwargs.pop(
                 "values",
                 [
@@ -31,5 +30,5 @@ class CategoryorderValidator(_plotly_utils.basevalidators.EnumeratedValidator):
                     "median descending",
                 ],
             ),
-            **kwargs
+            **kwargs,
         )
