@@ -9,6 +9,5 @@ class PrefixValidator(_plotly_utils.basevalidators.StringValidator):
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "arraydraw"),
-            role=kwargs.pop("role", "info"),
-            **kwargs
+            **kwargs,
         )
