@@ -11,5 +11,5 @@ class NamelengthValidator(_plotly_utils.basevalidators.IntegerValidator):
             array_ok=kwargs.pop("array_ok", True),
             edit_type=kwargs.pop("edit_type", "calc"),
             min=kwargs.pop("min", -1),
-            **kwargs
+            **kwargs,
         )
