@@ -6,11 +6,11 @@ class ColorValidator(_plotly_utils.basevalidators.ColorValidator):
         self,
         plotly_name="color",
         parent_name="scatter3d.marker.colorbar.tickfont",
-        **kwargs
+        **kwargs,
     ):
         super(ColorValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "calc"),
-            **kwargs
+            **kwargs,
         )
