@@ -6,12 +6,11 @@ class ColorValidator(_plotly_utils.basevalidators.ColorValidator):
         self,
         plotly_name="color",
         parent_name="scattercarpet.marker.colorbar.title.font",
-        **kwargs
+        **kwargs,
     ):
         super(ColorValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "colorbars"),
-            role=kwargs.pop("role", "style"),
-            **kwargs
+            **kwargs,
         )
