@@ -10,7 +10,6 @@ class TextpositionValidator(_plotly_utils.basevalidators.EnumeratedValidator):
             parent_name=parent_name,
             array_ok=kwargs.pop("array_ok", True),
             edit_type=kwargs.pop("edit_type", "calc"),
-            role=kwargs.pop("role", "style"),
             values=kwargs.pop(
                 "values",
                 [
@@ -25,5 +24,5 @@ class TextpositionValidator(_plotly_utils.basevalidators.EnumeratedValidator):
                     "bottom right",
                 ],
             ),
-            **kwargs
+            **kwargs,
         )
