@@ -6,7 +6,7 @@ class FamilyValidator(_plotly_utils.basevalidators.StringValidator):
         self,
         plotly_name="family",
         parent_name="scatterternary.legendgrouptitle.font",
-        **kwargs
+        **kwargs,
     ):
         super(FamilyValidator, self).__init__(
             plotly_name=plotly_name,
@@ -14,5 +14,5 @@ class FamilyValidator(_plotly_utils.basevalidators.StringValidator):
             edit_type=kwargs.pop("edit_type", "style"),
             no_blank=kwargs.pop("no_blank", True),
             strict=kwargs.pop("strict", True),
-            **kwargs
+            **kwargs,
         )
