@@ -7,5 +7,5 @@ class ShowupperhalfValidator(_plotly_utils.basevalidators.BooleanValidator):
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "calc"),
-            **kwargs
+            **kwargs,
         )
